@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "persp-mode" "3.0.9"
+(define-package "persp-mode" "20250830.955"
   "Windows/buffers sets shared among frames + save/load."
   '((emacs "24.3"))
   :url "https://github.com/Bad-ptr/persp-mode.el"
-  :commit "40e9993a9711cba5fb56dfec81a507fabeba9668"
-  :revdesc "40e9993a9711"
+  :commit "fab4bf76927445d2e431f06e74572acba81f47d5"
+  :revdesc "fab4bf769274"
   :keywords '("perspectives" "session" "workspace" "persistence" "windows" "buffers" "convenience")
   :authors '(("Constantin Kulikov" . "zxnotdead@gmail.com"))
   :maintainers '(("Constantin Kulikov" . "zxnotdead@gmail.com")))
